@@ -37,7 +37,8 @@ class TestPathutils(LazygalTest):
         """
         Create a working directory in a test location if it does not exist.
         """
-        if dpath[0] == '/': dpath = dpath[1:]
+        if dpath[0] == "/":
+            dpath = dpath[1:]
 
         dpath = os.path.join(self.test_root, dpath)
         if not os.path.exists(dpath):
@@ -52,48 +53,47 @@ class TestPathutils(LazygalTest):
         dpath = self.d(os.path.dirname(fpath))
         fpath = os.path.join(dpath, os.path.basename(fpath))
         if not os.path.exists(fpath):
-            with open(fpath, 'a'):
+            with open(fpath, "a"):
                 os.utime(fpath, None)
         assert os.path.isfile(fpath)
         return fpath
 
     def test_is_subdir_of_dirs(self):
-        self.assertTrue(is_subdir_of(self.d('/tmp'), self.d('/tmp/foo')))
-        self.assertFalse(is_subdir_of(self.d('/tmp'), self.d('/tmpx/foo')))
-        self.assertTrue(is_subdir_of(self.d('/tmp/bar'),
-                                     self.f('/tmp/bar/baz/jay')))
-        self.assertFalse(is_subdir_of(self.d('/tmp/john/mail'), self.d('/tmpz')))
+        self.assertTrue(is_subdir_of(self.d("/tmp"), self.d("/tmp/foo")))
+        self.assertFalse(is_subdir_of(self.d("/tmp"), self.d("/tmpx/foo")))
+        self.assertTrue(is_subdir_of(self.d("/tmp/bar"), self.f("/tmp/bar/baz/jay")))
+        self.assertFalse(is_subdir_of(self.d("/tmp/john/mail"), self.d("/tmpz")))
 
     def test_is_subdir_of_files(self):
-        self.assertTrue(is_subdir_of(self.d('/tmp'), self.f('/tmp/foo')))
-        self.assertFalse(is_subdir_of(self.d('/tmp'),
-                                      self.f('/tmpx/foo')))
-        self.assertTrue(is_subdir_of(self.d('/tmp/bar'),
-                                     self.f('/tmp/bar/baz/jay')))
-        self.assertFalse(is_subdir_of(self.d('/tmp/john/mail'), self.f('/tmpz')))
+        self.assertTrue(is_subdir_of(self.d("/tmp"), self.f("/tmp/foo")))
+        self.assertFalse(is_subdir_of(self.d("/tmp"), self.f("/tmpx/foo")))
+        self.assertTrue(is_subdir_of(self.d("/tmp/bar"), self.f("/tmp/bar/baz/jay")))
+        self.assertFalse(is_subdir_of(self.d("/tmp/john/mail"), self.f("/tmpz")))
 
     def test_url_path(self):
-        self.assertEqual(url_path('/usr/bin/lazygal', posixpath),
-                         '/usr/bin/lazygal')
-        self.assertEqual(url_path('../bin/lazygal', posixpath),
-                         '../bin/lazygal')
-        self.assertEqual(url_path('C:\\Program Files\\Lazygal\\Lazygal.exe',
-                                  ntpath),
-                         'Program Files/Lazygal/Lazygal.exe')
-        self.assertEqual(url_path('..\\Lazygal\\Lazygal.exe', ntpath),
-                         '../Lazygal/Lazygal.exe')
+        self.assertEqual(url_path("/usr/bin/lazygal", posixpath), "/usr/bin/lazygal")
+        self.assertEqual(url_path("../bin/lazygal", posixpath), "../bin/lazygal")
+        self.assertEqual(
+            url_path("C:\\Program Files\\Lazygal\\Lazygal.exe", ntpath),
+            "Program Files/Lazygal/Lazygal.exe",
+        )
+        self.assertEqual(
+            url_path("..\\Lazygal\\Lazygal.exe", ntpath), "../Lazygal/Lazygal.exe"
+        )
 
     def test_url_quote(self):
-        self.assertEqual(url_quote('http://host:8080/~user/album/'),
-                         'http://host:8080/~user/album/')
-        self.assertEqual(url_quote('https://host/~user/album/'),
-                         'https://host/~user/album/')
-        self.assertEqual(url_quote(u'/albumé/'), '/album%C3%A9/')
-        self.assertEqual(url_quote('filter: user/'), 'filter%3A%20user/')
-        self.assertEqual(url_quote('index.html', 'id'), 'index.html#id')
+        self.assertEqual(
+            url_quote("http://host:8080/~user/album/"), "http://host:8080/~user/album/"
+        )
+        self.assertEqual(
+            url_quote("https://host/~user/album/"), "https://host/~user/album/"
+        )
+        self.assertEqual(url_quote("/albumé/"), "/album%C3%A9/")
+        self.assertEqual(url_quote("filter: user/"), "filter%3A%20user/")
+        self.assertEqual(url_quote("index.html", "id"), "index.html#id")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
 
 
