@@ -11,5 +11,5 @@ im = GExiv2.Metadata(fn)
 
 # Assume comment is in utf-8, more encoding processing example using
 # sys.stdin.encoding and example processing in lazygal/metadata.py
-im['Exif.Photo.UserComment'] = comment
+im["Exif.Photo.UserComment"] = comment
 im.save_file()
